%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% text2morse.m
% version 1.0
% developed by J. Fiene and G. Johnson
% University of Pennsylvania
% September 13, 2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function morse_string = text2morse(plaintext)
% takes in a plaintext string and outputs a string of numbers corresponding
% to Morse Code, where:
%   0 is an inter-character space
%   1 is a DIT
%   2 is a DAH
%   3 is an inter-word space 
% you can use the following for input:
%   all 26 characters
%   all 10 digits
%   the following punctuation: !"$&'()+'-./:;=?@

ascii_offset = 31; % space is '32'

% lookup table corresponding to ascii code, starting with space (32)
morse_codes = {
    [3]
    [2 1 2 1 2 2]
    [1 2 1 1 2 1]
    []
    [1 1 1 2 1 1 2]
    []
    [1 2 1 1 1]
    [1 2 2 2 2 1]
    [2 1 2 2 1]
    [2 1 2 2 1 2]
    []
    [1 2 1 2 1]
    [2 2 1 1 2 2]
    [2 1 1 1 1 2]
    [1 2 1 2 1 2]
    [2 1 1 2 1]
    [2 2 2 2 2]
    [1 2 2 2 2]
    [1 1 2 2 2]
    [1 1 1 2 2]
    [1 1 1 1 2]
    [1 1 1 1 1]
    [2 1 1 1 1]
    [2 2 1 1 1]
    [2 2 2 1 1]
    [2 2 2 2 1]
    [2 2 2 1 1 1]
    [2 1 2 1 2 1]
    []
    [2 1 1 1 2]
    []
    [1 1 2 2 1 1]
    [1 2 2 1 2 1]
    [1 2] 
    [2 1 1 1]
    [2 1 2 1]
    [2 1 1]
    [1]
    [1 1 2 1]
    [2 2 1]
    [1 1 1 1]
    [1 1]
    [1 2 2 2]
    [2 1 2]
    [1 2 1 1]
    [2 2]
    [2 1]
    [2 2 2]
    [1 2 2 1]
    [2 2 1 2]
    [1 2 1]
    [1 1 1]
    [2]
    [1 1 2]
    [1 1 1 2]
    [1 2 2]
    [2 1 1 2]
    [2 1 2 2]
    [2 2 1 1]
    []
    []
    []
    []
    []
    []
    [1 2] 
    [2 1 1 1]
    [2 1 2 1]
    [2 1 1]
    [1]
    [1 1 2 1]
    [2 2 1]
    [1 1 1 1]
    [1 1]
    [1 2 2 2]
    [2 1 2]
    [1 2 1 1]
    [2 2]
    [2 1]
    [2 2 2]
    [1 2 2 1]
    [2 2 1 2]
    [1 2 1]
    [1 1 1]
    [2]
    [1 1 2]
    [1 1 1 2]
    [1 2 2]
    [2 1 1 2]
    [2 1 2 2]
    [2 2 1 1]
    []
    []
    []
    []
    []
};

% the actual code:
morse_string = [];
ascii_input = unicode2native(plaintext);
for(i=1:length(ascii_input))
    morse_string = [morse_string morse_codes{ascii_input(i)-ascii_offset} 0];
end